/*
 * libtdm logging subsystem
 *
 */
#ifndef _TDM_LOG_H_
#define _TDM_LOG_H_

typedef enum {
	TDM_LOG_NONE = 0,
	TDM_LOG_EMERGENCY,
	TDM_LOG_CRITICAL,
	TDM_LOG_ALERT,
	TDM_LOG_ERROR,
	TDM_LOG_WARNING,
	TDM_LOG_NOTICE,
	TDM_LOG_INFO,
	TDM_LOG_DEBUG,
	TDM_LOG_INVALID
} tdm_loglevel_t;


TDM_API tdm_status_t
__tdm_log(const tdm_loglevel_t level, const void *p1, const void *p2, const char *fmt, ...);

TDM_API tdm_status_t
__tdm_printf(const void *p1, const void *p2, const char *fmt, ...);

#define tdm_log(level, fmt, args...) \
	__tdm_log(level, NULL, NULL, fmt, ##args)

/* public (maybe only modules api), convenience macros */
#define tdm_info(fmt, args...)	\
	__tdm_log(TDM_LOG_INFO, NULL, NULL, fmt, ##args)

#define tdm_notice(fmt, args...)	\
	__tdm_log(TDM_LOG_NOTICE, NULL, NULL, fmt, ##args)

#define tdm_error(fmt, args...)	\
	__tdm_log(TDM_LOG_ERROR, NULL, NULL, fmt, ##args)

#define tdm_warn(fmt, args...)	\
	__tdm_log(TDM_LOG_WARNING, NULL, NULL, fmt, ##args)

#define tdm_debug(fmt, args...)	\
	__tdm_log(TDM_LOG_DEBUG, NULL, NULL, fmt, ##args)

#define tdm_printf(fmt, args...)	\
	__tdm_printf(NULL, NULL, fmt, ##args)


TDM_API tdm_status_t
tdm_set_loglevel(const tdm_loglevel_t level);

TDM_API tdm_loglevel_t
tdm_get_loglevel(void);

TDM_API const char *
tdm_loglevel_get_name(const tdm_loglevel_t level);

TDM_API const tdm_loglevel_t
tdm_loglevel_get_id(const char *name);

TDM_API tdm_status_t
tdm_log_init(void);

#endif /* _TDM_LOG_H_ */
